RGCNLayer
=========

.. currentmodule:: pykeen.nn.message_passing

.. autoclass:: RGCNLayer
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~RGCNLayer.forward

   .. rubric:: Methods Documentation

   .. automethod:: forward
